@@ -1,66 +1,30 @@
 # -*- coding: utf-8 -*-
 
-from bs4 import BeautifulSoup
-from datetime import datetime
-from itertools import zip_longest
-from itertools import chain
-from textwrap import TextWrapper
-
 from toot import api, config
 from toot.auth import login_interactive, login_browser_interactive, create_app_interactive
 from toot.exceptions import ConsoleError, NotFoundError
-from toot.output import print_out, print_err, print_instance, print_account, print_search_results
+from toot.output import print_out, print_instance, print_account, print_search_results, print_timeline
 from toot.utils import assert_domain_exists
 
 
-def _print_timeline(item):
-    def wrap_text(text, width):
-        wrapper = TextWrapper(width=width, break_long_words=False, break_on_hyphens=False)
-        return chain(*[wrapper.wrap(l) for l in text.split("\n")])
-
-    def timeline_rows(item):
-        name = item['name']
-        time = item['time'].strftime('%Y-%m-%d %H:%M%Z')
-
-        left_column = [name, time]
-        if 'reblogged' in item:
-            left_column.append(item['reblogged'])
-
-        text = item['text']
-
-        right_column = wrap_text(text, 80)
-
-        return zip_longest(left_column, right_column, fillvalue="")
-
-    for left, right in timeline_rows(item):
-        print_out("{:30} │ {}".format(left, right))
-
-
-def _parse_timeline(item):
-    content = item['reblog']['content'] if item['reblog'] else item['content']
-    reblogged = item['reblog']['account']['username'] if item['reblog'] else ""
-
-    name = item['account']['display_name'] + " @" + item['account']['username']
-    soup = BeautifulSoup(content, "html.parser")
-    text = soup.get_text().replace('&apos;', "'")
-    time = datetime.strptime(item['created_at'], "%Y-%m-%dT%H:%M:%S.%fZ")
-
-    return {
-        "name": name,
-        "text": text,
-        "time": time,
-        "reblogged": reblogged,
-    }
-
-
 def timeline(app, user, args):
-    items = api.timeline_home(app, user)
-    parsed_items = [_parse_timeline(t) for t in items]
+    # Make sure tag, list and public are not used simultaneously
+    if len([arg for arg in [args.tag, args.list, args.public] if arg]) > 1:
+        raise ConsoleError("Only one of --public, --tag, or --list can be used at one time.")
 
-    print_out("─" * 31 + "┬" + "─" * 88)
-    for item in parsed_items:
-        _print_timeline(item)
-        print_out("─" * 31 + "┼" + "─" * 88)
+    if args.local and not (args.public or args.tag):
+        raise ConsoleError("The --local option is only valid alongside --public or --tag.")
+
+    if args.public:
+        items = api.timeline_public(app, user, local=args.local)
+    elif args.tag:
+        items = api.timeline_tag(app, user, args.tag, local=args.local)
+    elif args.list:
+        items = api.timeline_list(app, user, args.list)
+    else:
+        items = api.timeline_home(app, user)
+
+    print_timeline(items)
 
 
 def curses(app, user, args):
@@ -92,11 +56,24 @@ def post(app, user, args):
     if not args.text:
         raise ConsoleError("You must specify either text or media to post.")
 
-    response = api.post_status(app, user, args.text, args.visibility, media_ids)
+    response = api.post_status(
+        app, user, args.text,
+        visibility=args.visibility,
+        media_ids=media_ids,
+        sensitive=args.sensitive,
+        spoiler_text=args.spoiler_text,
+        in_reply_to_id=args.reply_to,
+    )
 
     print_out("Toot posted: <green>{}</green>".format(response.get('url')))
 
 
+def delete(app, user, args):
+    api.delete_status(app, user, args.status_id)
+
+    print_out("<green>✓ Status deleted</green>")
+
+
 def auth(app, user, args):
     config_data = config.load_config()
 
@@ -115,7 +92,7 @@ def auth(app, user, args):
     print_out("\nAuth tokens are stored in: <blue>{}</blue>".format(path))
 
 
-def login(app, user, args):
+def login_cli(app, user, args):
     app = create_app_interactive(instance=args.instance)
     login_interactive(app, args.email)
 
@@ -123,7 +100,7 @@ def login(app, user, args):
     print_out("<green>✓ Successfully logged in.</green>")
 
 
-def login_browser(app, user, args):
+def login(app, user, args):
     app = create_app_interactive(instance=args.instance)
     login_browser_interactive(app)
 
